summaryrefslogtreecommitdiff
path: root/t/colon7.sh
diff options
context:
space:
mode:
Diffstat (limited to 't/colon7.sh')
-rw-r--r--t/colon7.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/t/colon7.sh b/t/colon7.sh
index a3a66b443..b24132370 100644
--- a/t/colon7.sh
+++ b/t/colon7.sh
@@ -33,10 +33,10 @@ mkdir subdir
: > Makefile.am
: > subdir/foo
cat > subdir/Makefile.am << 'END'
# DIST_COMMON should contain 'foo', not 'subdir/foo'.
test:
- case '$(DIST_COMMON)' in *subdir/foo*) exit 1;; *) exit 0;; esac
- echo ' ' $(DIST_COMMON) ' ' | grep '[ /]foo '
+ case '$(am.dist.common-files)' in *subdir/foo*) exit 1;; *) exit 0;; esac
+ echo ' ' $(am.dist.common-files) ' ' | grep '[ /]foo '
.PHONY: test
END
@@ -33,10 +33,10 @@ mkdir subdir
: > subdir/foo
cat > subdir/Makefile.am << 'END'
-# DIST_COMMON should contain 'foo', not 'subdir/foo'.
+# am.dist.common-files should contain 'foo', not 'subdir/foo'.
test: